@@ -49,8 +49,8 @@ def create_full_spm_subpipes(
     Inputs:
 
         inputnode:
-            T1: T1 file name
-            T2: T2 file name
+            list_T1: T1 file names
+            list_T2: T2 file names
 
             indiv_params (opt): dict with individuals parameters for some nodes
 
@@ -61,7 +61,7 @@ def create_full_spm_subpipes(
 
             params: dictionary of node sub-parameters (from a json file)
 
-            name: pipeline name (default = "T1xT2_segmentation_pipeline")
+            name: pipeline name (default = "full_spm_subpipes")
 
     Outputs:
             old_segment_pipe.thresh_gm.out_file:
@@ -87,8 +87,6 @@ def create_full_spm_subpipes(
 
     # preprocessing
     if 'short_preparation_pipe' in params.keys():
-        assert 'bet_crop' in parse_key(params, "short_preparation_pipe"),\
-            "This version should contains betcrop in params.json"
 
         data_preparation_pipe = create_short_preparation_pipe(
             params=parse_key(params, "short_preparation_pipe"))
@@ -113,12 +111,12 @@ def create_full_spm_subpipes(
                      debias, 't1_file')
     seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T2',
                      debias, 't2_file')
-    seg_pipe.connect(data_preparation_pipe, 'bet_crop.mask_file',
-                     debias, 'b')
 
-    seg_pipe.connect(
-        inputnode, ('indiv_params', parse_key, "debias"),
-        debias, 'indiv_params')
+    if 'bet_crop' in parse_key(params, "short_preparation_pipe"):
+        seg_pipe.connect(data_preparation_pipe, 'bet_crop.mask_file',
+                         debias, 'b')
+    else:
+        debias.inputs.bet = 1
 
     # Iterative registration to the INIA19 template
     reg = NodeParams(IterREGBET(),
@@ -156,7 +154,45 @@ def create_full_spm_subpipes(
 # SPM based, but only T1 is available (-soft SPM_T1)
 def create_full_T1_spm_subpipes(
         params_template, params={}, name='full_T1_spm_subpipes'):
-    """
+    """ Description: SPM based segmentation pipeline from T1w image only.
+        This is fact the same as create_full_spm_subpipes, where T2 is
+        replaced by T1
+
+        - data_preparation_pipe:
+            - avg_align
+            - deoblique,
+            - reorient if needed
+            - bet_crop (brain extraction and crop) -> mask
+            - denoise
+        - T1xT2BiasFieldCorrection using mask -> debias
+        - IterREGBET -> registration to template file
+        - old_segment_pipe
+
+    Inputs:
+
+        inputnode:
+            list_T1: T1 file names
+
+            indiv_params (opt): dict with individuals parameters for some nodes
+
+
+        arguments:
+            params_template: dict of template files containing brain_template
+            and priors (list of template based segmented tissues)
+
+            params: dictionary of node sub-parameters (from a json file)
+
+            name: pipeline name (default = "full_spm_subpipes")
+
+    Outputs:
+            old_segment_pipe.thresh_gm.out_file:
+                segmented grey matter in template space
+
+            old_segment_pipe.thresh_wm.out_file:
+                segmented white matter in template space
+
+            old_segment_pipe.thresh_csf.out_file:
+                segmented csf in template space
     """
 
     print("Full pipeline name: ", name)
@@ -171,8 +207,14 @@ def create_full_T1_spm_subpipes(
     )
 
     # preprocessing
-    data_preparation_pipe = create_short_preparation_pipe(
-        params=parse_key(params, "short_preparation_pipe"))
+    # preprocessing
+    if 'short_preparation_pipe' in params.keys():
+        data_preparation_pipe = create_short_preparation_pipe(
+            params=parse_key(params, "short_preparation_pipe"))
+    else:
+        print("Error, short_preparation_pipe was not \
+            found in params, skipping")
+        return seg_pipe
 
     seg_pipe.connect(inputnode, 'list_T1',
                      data_preparation_pipe, 'inputnode.list_T1')
@@ -190,8 +232,13 @@ def create_full_T1_spm_subpipes(
                      debias, 't1_file')
     seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T1',
                      debias, 't2_file')
-    seg_pipe.connect(data_preparation_pipe, 'bet_crop.mask_file',
-                     debias, 'b')
+
+    if 'bet_crop' in parse_key(params, "short_preparation_pipe"):
+        seg_pipe.connect(data_preparation_pipe, 'bet_crop.mask_file',
+                         debias, 'b')
+    else:
+        debias.inputs.bet = 1
+
     seg_pipe.connect(
         inputnode, ('indiv_params', parse_key, "debias"),
         debias, 'indiv_params')
@@ -243,7 +290,6 @@ def create_full_T1_spm_subpipes(
 # ANTS based segmentation (from Kepkee Loh / Julien Sein)
 
 
-# same as before, but with indiv_params
 def create_brain_extraction_pipe(params_template, params={},
                                  name="brain_extraction_pipe"):
     """ Description: ANTS based segmentation pipeline using T1w and T2w images
@@ -391,7 +437,7 @@ def create_brain_segment_from_mask_pipe(
 
 # (-soft ANTS)
 def create_full_ants_subpipes(
-        params_template, params={}, name="full_ants_subpipes"):
+        params_template, params={}, name="full_ants_subpipes", mask_file=None):
     """Description: Segment T1 (using T2 for bias correction) .
 
     new version (as it is now)
@@ -409,9 +455,9 @@ def create_full_ants_subpipes(
     Inputs:
 
         inputnode:
-            preproc_T1: preprocessed T1 file name
+            list_T1: preprocessed T1 file name
 
-            preproc_T2: preprocessed T2 file name
+            list_T2: preprocessed T2 file name
 
             indiv_params (opt): dict with individuals parameters for some nodes
 
@@ -470,21 +516,23 @@ def create_full_ants_subpipes(
     seg_pipe.connect(inputnode, 'indiv_params',
                      data_preparation_pipe, 'inputnode.indiv_params')
 
-    # full extract brain pipeline (correct_bias, denoising, extract brain)
-    if "brain_extraction_pipe" not in params.keys():
-        return seg_pipe
+    if mask_file is None:
 
-    brain_extraction_pipe = create_brain_extraction_pipe(
-        params=parse_key(params, "brain_extraction_pipe"),
-        params_template=params_template)
+        # full extract brain pipeline (correct_bias, denoising, extract brain)
+        if "brain_extraction_pipe" not in params.keys():
+            return seg_pipe
 
-    seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T1',
-                     brain_extraction_pipe, 'inputnode.preproc_T1')
-    seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T2',
-                     brain_extraction_pipe, 'inputnode.preproc_T2')
+        brain_extraction_pipe = create_brain_extraction_pipe(
+            params=parse_key(params, "brain_extraction_pipe"),
+            params_template=params_template)
 
-    seg_pipe.connect(inputnode, 'indiv_params',
-                     brain_extraction_pipe, 'inputnode.indiv_params')
+        seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T1',
+                         brain_extraction_pipe, 'inputnode.preproc_T1')
+        seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T2',
+                         brain_extraction_pipe, 'inputnode.preproc_T2')
+
+        seg_pipe.connect(inputnode, 'indiv_params',
+                         brain_extraction_pipe, 'inputnode.indiv_params')
 
     # full_segment (restarting from the avg_align files)
     if "brain_segment_pipe" not in params.keys():
@@ -498,9 +546,14 @@ def create_full_ants_subpipes(
                      brain_segment_pipe, 'inputnode.preproc_T1')
     seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T2',
                      brain_segment_pipe, 'inputnode.preproc_T2')
-    seg_pipe.connect(brain_extraction_pipe,
-                     "extract_pipe.smooth_mask.out_file",
-                     brain_segment_pipe, "inputnode.brain_mask")
+
+    if mask_file is None:
+        seg_pipe.connect(brain_extraction_pipe,
+                         "extract_pipe.smooth_mask.out_file",
+                         brain_segment_pipe, "inputnode.brain_mask")
+    else:
+        brain_segment_pipe.inputs.inputnode.brain_mask = mask_file
+
     seg_pipe.connect(inputnode, 'indiv_params',
                      brain_segment_pipe, 'inputnode.indiv_params')
 
@@ -534,7 +587,9 @@ def create_full_ants_subpipes(
 
     return seg_pipe
 
-# ################# ANTS based segmentation for adrien baboons (T1 without T2)
+###############################################################################
+# ANTS based segmentation for adrien baboons (T1 without T2)
+###############################################################################
 
 
 # same as above, but replacing biascorrection with N4biascorrection
@@ -598,8 +653,6 @@ def create_brain_segment_from_mask_T1_pipe(
         inputnode:
             preproc_T1: preprocessed T1 file name
 
-            preproc_T2: preprocessed T2 file name
-
             brain_mask: a mask computed for the same T1/T2 images
 
             indiv_params (opt): dict with individuals parameters for some nodes
@@ -686,9 +739,7 @@ def create_full_T1_ants_subpipes(
     Inputs:
 
         inputnode:
-            preproc_T1: preprocessed T1 file name
-
-            preproc_T2: preprocessed T2 file name
+            list_T1: preprocessed T1 file name
 
             indiv_params (opt): dict with individuals parameters for some nodes
 
