@@ -16,7 +16,6 @@ from ..nodes.extract_brain import T1xT2BET
 
 def _create_reorient_pipeline(name="reorient_pipe",
                               new_dims=("x", "z", "-y")):
-
     """
     By kepkee:
     fslswapdim image_bad x z -y image_good
@@ -50,7 +49,6 @@ def _create_reorient_pipeline(name="reorient_pipe",
 
 def _create_mapnode_reorient_pipeline(name="reorient_pipe",
                                       new_dims=("x", "z", "-y")):
-
     """
     By kepkee:
     fslswapdim image_bad x z -y image_good
@@ -98,18 +96,18 @@ def _create_prep_pipeline(params, name="prep_pipeline"):
 
     # Reorient if needed
     if "reorient" in params.keys():
-
+        print("adding reorient pipeline")
         if "new_dims" in params["reorient"].keys():
             new_dims = tuple(params["reorient"]["new_dims"].split())
-
+            print("using new dim")
         else:
             new_dims = ("x", "z", "-y")
 
-            reorient_pipe = _create_reorient_pipeline(
-                name="reorient_pipe", new_dims=new_dims)
+        reorient_pipe = _create_reorient_pipeline(
+            name="reorient_pipe", new_dims=new_dims)
 
-            prep_pipeline.connect(inputnode, 'img',
-                                  reorient_pipe, 'inputnode.img')
+        prep_pipeline.connect(inputnode, 'img',
+                              reorient_pipe, 'inputnode.image')
 
     if "denoise_first" in params.keys():
         # denoise with Ants package
@@ -119,7 +117,7 @@ def _create_prep_pipeline(params, name="prep_pipeline"):
                                    name="denoise")
 
         if "reorient" in params.keys():
-            prep_pipeline.connect(reorient_pipe, 'swap_dim.out_file',
+            prep_pipeline.connect(reorient_pipe, 'reorient.out_file',
                                   denoise_first, 'input_image')
         else:
             prep_pipeline.connect(inputnode, 'img',
@@ -136,7 +134,7 @@ def _create_prep_pipeline(params, name="prep_pipeline"):
         prep_pipeline.connect(denoise_first, 'output_image',
                               crop, 'in_file')
     elif "reorient" in params.keys():
-        prep_pipeline.connect(reorient_pipe, 'swap_dim.out_file',
+        prep_pipeline.connect(reorient_pipe, 'reorient.out_file',
                               crop, 'in_file')
     else:
         prep_pipeline.connect(inputnode, 'img',
@@ -229,7 +227,7 @@ def _create_mapnode_prep_pipeline(params, name="mapnode_prep_pipeline"):
             iterfield=["input_image"])
 
         if "reorient" in params.keys():
-            mapnode_prep_pipeline.connect(reorient_pipe, 'swap_dim.out_file',
+            mapnode_prep_pipeline.connect(reorient_pipe, 'reorient.out_file',
                                           denoise_first, 'input_image')
         else:
             mapnode_prep_pipeline.connect(inputnode, 'list_img',
@@ -246,7 +244,7 @@ def _create_mapnode_prep_pipeline(params, name="mapnode_prep_pipeline"):
         mapnode_prep_pipeline.connect(denoise_first, 'output_image',
                                       crop, 'in_file')
     elif "reorient" in params.keys():
-        mapnode_prep_pipeline.connect(reorient_pipe, 'swap_dim.out_file',
+        mapnode_prep_pipeline.connect(reorient_pipe, 'reorient.out_file',
                                       crop, 'in_file')
     else:
         mapnode_prep_pipeline.connect(inputnode, 'list_img',
@@ -304,7 +302,6 @@ def _create_mapnode_prep_pipeline(params, name="mapnode_prep_pipeline"):
 # choices between the 3 main pipelines: "short", "long_single" et "long_multi"
 ###############################################################################
 def create_short_preparation_pipe(params, name="short_preparation_pipe"):
-
     """Description: old data preparation:, T1s and T2s are averaged
     (by modality) and then average imgs are processed:
 
@@ -387,10 +384,10 @@ def create_short_preparation_pipe(params, name="short_preparation_pipe"):
         if "reorient" in params.keys():
 
             data_preparation_pipe.connect(reorient_T1_pipe,
-                                          'swap_dim.out_file',
+                                          'reorient.out_file',
                                           bet_crop, 't1_file')
             data_preparation_pipe.connect(reorient_T2_pipe,
-                                          'swap_dim.out_file',
+                                          'reorient.out_file',
                                           bet_crop, 't2_file')
         else:
             data_preparation_pipe.connect(av_T1, 'avg_img',
@@ -421,14 +418,14 @@ def create_short_preparation_pipe(params, name="short_preparation_pipe"):
 
         if "reorient" in params.keys():
             data_preparation_pipe.connect(reorient_T1_pipe,
-                                          'swap_dim.out_file',
+                                          'reorient.out_file',
                                           align_T2_on_T1, 'reference')
             data_preparation_pipe.connect(reorient_T2_pipe,
-                                          'swap_dim.out_file',
+                                          'reorient.out_file',
                                           align_T2_on_T1, 'in_file')
 
             data_preparation_pipe.connect(reorient_T1_pipe,
-                                          'swap_dim.out_file',
+                                          'reorient.out_file',
                                           crop_T1, 'in_file')
         else:
             data_preparation_pipe.connect(av_T1, 'avg_img',
@@ -759,10 +756,10 @@ def create_short_preparation_T1_pipe(params,
         if "reorient" in params.keys():
 
             data_preparation_pipe.connect(reorient_T1_pipe,
-                                          'swap_dim.out_file',
+                                          'reorient.out_file',
                                           bet_crop, 't1_file')
             data_preparation_pipe.connect(reorient_T1_pipe,
-                                          'swap_dim.out_file',
+                                          'reorient.out_file',
                                           bet_crop, 't2_file')
         else:
             data_preparation_pipe.connect(av_T1, 'avg_img',
@@ -784,7 +781,7 @@ def create_short_preparation_T1_pipe(params,
 
         if "reorient" in params.keys():
             data_preparation_pipe.connect(reorient_T1_pipe,
-                                          'swap_dim.out_file',
+                                          'reorient.out_file',
                                           crop_T1, 'in_file')
         else:
             data_preparation_pipe.connect(av_T1, 'avg_img',
